Bias
====

Measuring
---------

Here are some tutorials where different systems are assessed using the metrics.

- `Measuring Bias Classification <bias/measuring_bias/measuring_bias_classification.ipynb>`_
- `Measuring Bias Regression <bias/measuring_bias/measuring_bias_regression.ipynb>`_
- `Measuring Bias Recommender <bias/measuring_bias/measuring_bias_recommender.ipynb>`_
- `Measuring Bias Clustering <bias/measuring_bias/measuring_bias_clustering.ipynb>`_
- `Measuring Bias Multiclass <bias/measuring_bias/measuring_bias_multiclass.ipynb>`_

Mitigation
----------

Here are some tutorials where different systems are fitting using the mitigators.

- Binary Classification
    - Demos
        - `Preprocessing Bias Mitigation for Binary Classification <bias/mitigating_bias/binary_classification/demos/preprocessing.ipynb>`_
        - `Inprocessing Bias Mitigation for Binary Classification <bias/mitigating_bias/binary_classification/demos/inprocessing.ipynb>`_
        - `Postprocessing Bias Mitigation for Binary Classification <bias/mitigating_bias/binary_classification/demos/postprocessing.ipynb>`_
    - Examples
        - `Census Data Analysis <bias/mitigating_bias/binary_classification/examples/example_census_data.ipynb>`_

- Regression
    - Demos
        - `Preprocessing Bias Mitigation for Regression <bias/mitigating_bias/regression/demos/preprocessing.ipynb>`_
        - `Inprocessing Bias Mitigation for Regression <bias/mitigating_bias/regression/demos/inprocessing.ipynb>`_
        - `Postprocessing Bias Mitigation for Regression <bias/mitigating_bias/regression/demos/postprocessing.ipynb>`_
    - Examples
        - `Case study: Mitigating Bias in "Communities and Crime" dataset <bias/mitigating_bias/regression/examples/example_us_crime.ipynb>`_

- Multiclass Classification
    - Demos
        - `Preprocessing Bias Mitigation for Multiclass Classification <bias/mitigating_bias/multi_classification/demos/preprocessing.ipynb>`_
        - `Inprocessing Bias Mitigation for Multiclass Classification <bias/mitigating_bias/multi_classification/demos/inprocessing.ipynb>`_
        - `Postprocessing Bias Mitigation for Multiclass Classification <bias/mitigating_bias/multi_classification/demos/postprocessing.ipynb>`_
    - Examples
        - `Bias Mitigation in US Crime Data <bias/mitigating_bias/multi_classification/examples/example_multiclassification.ipynb>`_

- Recommender Systems
    - Demos
        - `Inprocessing Bias Mitigation for Recommender Systems <bias/mitigating_bias/recommender_systems/demos/inprocessing.ipynb>`_
        - `Postprocessing Bias Mitigation for Recommender Systems <bias/mitigating_bias/recommender_systems/demos/postprocessing.ipynb>`_
    - Examples
        - `Case study: Mitigating Bias in "LastFM" dataset <bias/mitigating_bias/recommender_systems/examples/example_lastfm.ipynb>`_
        
- Clustering
    - Demos
        - `Preprocessing Bias Mitigation for Clustering <bias/mitigating_bias/clustering/demos/preprocessing.ipynb>`_
        - `Inprocessing Bias Mitigation for Clustering <bias/mitigating_bias/clustering/demos/inprocessing.ipynb>`_
        - `Postprocessing Bias Mitigation for Clustering <bias/mitigating_bias/clustering/demos/postprocessing.ipynb>`_
    - Examples
        - `Bias Mitigation in Clinical Records <bias/mitigating_bias/clustering/examples/example_clustering.ipynb>`_
